betty.json package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.json package

## Submodules

- betty.json.linked_data module
  - `JsonLdSchema`
    - `JsonLdSchema.new()`
    - `JsonLdSchema.wrap()`
  - `LinkedDataDumpable`
    - `LinkedDataDumpable.dump_linked_data()`
    - `LinkedDataDumpable.linked_data_schema()`
  - `dump_context()`
  - `dump_link()`
- betty.json.schema module
  - `ArraySchema`
    - `ArraySchema.__init__()`
  - `Def`
    - `Def.__new__()`
  - `FileBasedSchema`
    - `FileBasedSchema.new_for()`
  - `JsonSchemaReference`
    - `JsonSchemaReference.__init__()`
  - `JsonSchemaSchema`
    - `JsonSchemaSchema.new()`
  - `Ref`
    - `Ref.__init__()`
  - `Schema`
    - `Schema.__init__()`
    - `Schema.def_name`
    - `Schema.defs`
    - `Schema.embed()`
    - `Schema.schema`
    - `Schema.validate()`
  - `add_property()`

## Module contents

Provide JSON utilities.